// a flanger
//
// Programmer:    Craig Stuart Sapp <craig@ccrma.stanford.edu>
// Creation Date: Wed Apr 30 21:50:42 GMT-0800 1997
// Last Modified: Thu May  1 22:48:51 GMT-0800 1997
// Filename:      .../sig/examples/flanger/flanger3.cc
// Syntax:        C++ 
// $Smake:        smake -v `architecture` %f
// $Smake-next:   cc -Wall -O -o %b.next %f -I../../../include %
//                -L../../../lib -lg++ %
//                -lsig_next && strip %b.next && rm -f %b && ln -s %b.next %b
// $Smake-linux:  cc -Wall -O -o %b.linux %f -I../../../include %
//                -L../../../lib -lg++ %
//                -lsig_linux && strip %b.linux && rm -f %b && ln -s %b.linux %b
//

#include "Dependencies.h"
#include <iostream.h>
#include <math.h>

Delayline *delayptr;

static sampleType flangeFunction(double input) {
   // several frequencies 0.23, 0.71, 0.25, 0.14
   return (
      delayptr->output(-200*(1+sin(0.000142475 * input * 100)) - 50)
   );
}


int main(int argc, char* argv[]) {
   if (argc != 3) {
      cerr << "Usage: " << argv[0] << " input.snd output.snd\n";
      exit(1); 
   }

   SoundHeader header(argv[1]);

   // Elements:
   SoundFileIn  insound(argv[1]);
   SoundFileOut outsound(argv[2], header);
   Function     oscdelay(flangeFunction);
   Add          add;
   Scale        scale(0.2);
   Delayline    delay(1000);
   Delayline    delay2(500);
   delayptr = &delay;

   // Connections:
   delay.connect(insound);
   delay2.connect(insound);
   add.connect(delay2);
   add.connect(oscdelay);
   scale.connect(add);
   outsound.connect(scale);

   int numSamples = header.getSamples() + 5;

   for (int i=0; i<numSamples; i++) {
      Tick(outsound);
      delay.action();
   }

   return 0;
}

