// mixes two soundfiles together with no delay object
//
// Programmer:    Craig Stuart Sapp <craig@ccrma.stanford.edu>
// Creation Date: Thu May  1 22:57:20 GMT-0800 1997
// Last Modified: Tue May  6 23:12:56 GMT-0800 1997
// Filename:      .../sig/examples/mix/mix.cc
// Syntax:        C++ 
// $Smake:        smake -v `architecture` %f
// $Smake-next:   cc -Wall -O -o %b.next %f -I../../include -L../../lib -lsig %
//                   -lg++ && strip %b.next && rm -f %b && ln -s %b.next %b
// $Smake-linux:  cc -Wall -O -o %b.linux %f -I../../include -L../../lib -lsig %

//

#include "Dependencies.h"
#include <iostream.h>

int main(int argc, char* argv[]) {
   if (argc != 4) {
      cerr << "Usage: " << argv[0] << " input1.snd input2.snd output.snd\n";
      exit(1); 
   }

   SoundHeader header(argv[1]);

   float s1, s2, offset;
   long offsetSamples = 0;
   cout << "Enter amplitude scaling of file 1: "; cin  >> s1;
   cout << "Enter amplitude scaling of file 2: "; cin  >> s2;
   cout << "Enter the time in seconds of offset of 2nd file: "; cin  >> offset;
   offsetSamples = (long)(offset * header.getSrate() + 0.5);

   // Elements:
   SoundFileIn  insound1(argv[1]);
   SoundFileIn  insound2(argv[2]);
   if (insound2.getChannels() == 2) {
      header.setChannels(2);
   }
   SoundFileOut outsound(argv[3], header);
   Add          addLeft;
   Add          addRight;
   Scale        leftScale1(s1);
   Scale        rightScale1(s1);
   Scale        leftScale2(s2);
   Scale        rightScale2(s2);
   Constant     constant(0);


   // Connections:
   leftScale1.connect(insound1);
   leftScale2.connect(constant);
   addLeft.connect(leftScale1);
   addLeft.connect(leftScale2);
   outsound.connect(addLeft);


   if (header.getChannels() == 2) {
      rightScale1.connect(insound1, 0, 1);
      rightScale2.connect(constant, 0, 1);
      addRight.connect(rightScale2);
      addRight.connect(rightScale1);
      outsound.connect(addRight);
   }

   long samples1, samples2; 
   samples1 = insound1.getSamples();
   samples2 = insound2.getSamples() + offsetSamples;

   int numSamples = samples1 > samples2 ? samples1 : samples2;

   Action action;
   action.tick(outsound, offsetSamples);
   
   rightScale2.connect(insound2, 0, 1);      // replace constant read
   leftScale2.connect(insound2, 0);          // replace constant read
   action.tick(outsound, numSamples-offsetSamples);

   return 0;
}


