// make a soundfile with the specified moveable frequency/cycles sinewave
//
// Programmer:    Craig Stuart Sapp <craig@ccrma.stanford.edu>
// Creation Date: Sun May 11 22:45:14 GMT-0800 1997
// Last Modified: Sun May 25 00:45:55 GMT-0800 1997
// Filename:      .../sig/examples/osc/osc.cc
// Syntax:        C++ 
// $Smake:        smake -v `architecture` %f
// $Smake-next:   cc -Wall -O -o %b.next %f -I../../include -L../../lib -lg++ %
//                -lsig_next4i && strip %b.next && rm -f %b && ln -s %b.next %b
// $Smake-linux:  cc -Wall -O -o %b.linux %f -I../../include -L../../lib -lg++ %
//                -lsig_linux && strip %b.linux && rm -f %b && ln -s %b.linux %b
//

#include "Dependencies.h"

void exitUsage(char *commandName);


int main(int argc, char* argv[]) {
   if (argc != 4) exitUsage(argv[0]); 

   float duration;
   cout << "How many seconds does the sound last: ";
   cin  >> duration;

   int numSamples;
   numSamples = (int)(duration * 44100 + 0.5);
  
   SoundHeader header;
   header.setHighMono();

   // Elements:
   Osc          oscillator;
   oscillator.doLowQuality();
   SoundFileOut outsound(argv[3], header);
   Envelope     freqEnv(argv[1], numSamples);
   Envelope     ampEnv(argv[2], numSamples);

   // Connections:
   oscillator.connect(freqEnv, 0);
   oscillator.connect(ampEnv, 1);
   outsound.connect(oscillator);

   Action action;
   action.tick(outsound, numSamples);


   return 0;
}



void exitUsage(char* commandName) {
   cout << endl;
   cout << 
      "Frequency and amplitude varying sinusoid" << endl;
   cout << endl;
   cout << "Usage: " << commandName << " freqEnv ampEnv outsound" << endl;
   cout << endl;
   cout << "Program input: " << endl;
   cout << "   (a) time in seconds for output sound" << endl;
   cout << endl;

   exit(1);
}



